@@ -24,8 +24,9 @@ import scipy.signal as sps
 
 import cdl.algorithms.signal as alg
 from cdl.computation.base import (
+    ArithmeticParam,
     ClipParam,
-    ConstantOperationParam,
+    ConstantParam,
     FFTParam,
     GaussianParam,
     HistogramParam,
@@ -44,6 +45,23 @@ from cdl.obj import ResultProperties, ResultShape, ROI1DParam, SignalObj
 VALID_DTYPES_STRLIST = SignalObj.get_valid_dtypenames()
 
 
+def restore_data_outside_roi(dst: SignalObj, src: SignalObj) -> None:
+    """Restore data outside the region of interest, after a computation, only if the
+    source signal has a ROI, if the data types are the same and if the shapes are the
+    same. Otherwise, do nothing.
+
+    Args:
+        dst: destination signal object
+        src: source signal object
+    """
+    if (
+        src.maskdata is not None
+        and dst.xydata.dtype == src.xydata.dtype
+        and dst.xydata.shape == src.xydata.shape
+    ):
+        dst.xydata[src.maskdata] = src.xydata[src.maskdata]
+
+
 class Wrap11Func:
     """Wrap a 1 array → 1 array function (the simple case of y1 = f(y0)) to produce
     a 1 signal → 1 signal function, which can be used inside DataLab's infrastructure
@@ -98,6 +116,7 @@ class Wrap11Func:
         dst = dst_11(src, self.func.__name__, suffix)
         x, y = src.get_data()
         dst.set_xydata(x, self.func(y, *self.args, **self.kwargs))
+        restore_data_outside_roi(dst, src)
         return dst
 
 
@@ -126,6 +145,7 @@ def compute_addition(dst: SignalObj, src: SignalObj) -> SignalObj:
     dst.y += np.array(src.y, dtype=dst.y.dtype)
     if dst.dy is not None:
         dst.dy = np.sqrt(dst.dy**2 + src.dy**2)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
@@ -142,10 +162,11 @@ def compute_product(dst: SignalObj, src: SignalObj) -> SignalObj:
     dst.y *= np.array(src.y, dtype=dst.y.dtype)
     if dst.dy is not None:
         dst.dy = dst.y * np.sqrt((dst.dy / dst.y) ** 2 + (src.dy / src.y) ** 2)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
-def compute_addition_constant(src: SignalObj, p: ConstantOperationParam) -> SignalObj:
+def compute_addition_constant(src: SignalObj, p: ConstantParam) -> SignalObj:
     """Add **dst** and a constant value and return a the new result signal object
 
     Args:
@@ -157,10 +178,11 @@ def compute_addition_constant(src: SignalObj, p: ConstantOperationParam) -> Sign
     """
     dst = dst_11(src, "+", str(p.value))
     dst.y += p.value
+    restore_data_outside_roi(dst, src)
     return dst
 
 
-def compute_difference_constant(src: SignalObj, p: ConstantOperationParam) -> SignalObj:
+def compute_difference_constant(src: SignalObj, p: ConstantParam) -> SignalObj:
     """Subtract a constant value from a signal
 
     Args:
@@ -172,10 +194,11 @@ def compute_difference_constant(src: SignalObj, p: ConstantOperationParam) -> Si
     """
     dst = dst_11(src, "-", str(p.value))
     dst.y -= p.value
+    restore_data_outside_roi(dst, src)
     return dst
 
 
-def compute_product_constant(src: SignalObj, p: ConstantOperationParam) -> SignalObj:
+def compute_product_constant(src: SignalObj, p: ConstantParam) -> SignalObj:
     """Multiply **dst** by a constant value and return the new result signal object
 
     Args:
@@ -187,10 +210,11 @@ def compute_product_constant(src: SignalObj, p: ConstantOperationParam) -> Signa
     """
     dst = dst_11(src, "×", str(p.value))
     dst.y *= p.value
+    restore_data_outside_roi(dst, src)
     return dst
 
 
-def compute_division_constant(src: SignalObj, p: ConstantOperationParam) -> SignalObj:
+def compute_division_constant(src: SignalObj, p: ConstantParam) -> SignalObj:
     """Divide a signal by a constant value
 
     Args:
@@ -202,6 +226,7 @@ def compute_division_constant(src: SignalObj, p: ConstantOperationParam) -> Sign
     """
     dst = dst_11(src, "/", str(p.value))
     dst.y /= p.value
+    restore_data_outside_roi(dst, src)
     return dst
 
 
@@ -210,6 +235,44 @@ def compute_division_constant(src: SignalObj, p: ConstantOperationParam) -> Sign
 # --------------------------------------------------------------------------------------
 
 
+def compute_arithmetic(
+    src1: SignalObj, src2: SignalObj, p: ArithmeticParam
+) -> SignalObj:
+    """Perform arithmetic operation on two signals
+
+    Args:
+        src1: source signal 1
+        src2: source signal 2
+        p: parameters
+
+    Returns:
+        Result signal object
+    """
+    initial_dtype = src1.xydata.dtype
+    title = p.operation.replace("obj1", src1.short_id).replace("obj2", src2.short_id)
+    dst = src1.copy(title=title)
+    o, a, b = p.operator, p.factor, p.constant
+    if o in ("×", "/") and a == 0.0:
+        dst.y = np.ones_like(src1.y) * b
+    elif p.operator == "+":
+        dst.y = (src1.y + src2.y) * a + b
+    elif p.operator == "-":
+        dst.y = (src1.y - src2.y) * a + b
+    elif p.operator == "×":
+        dst.y = (src1.y * src2.y) * a + b
+    elif p.operator == "/":
+        dst.y = (src1.y / src2.y) * a + b
+    if dst.dy is not None and p.operator in ("+", "-"):
+        dst.dy = np.sqrt(src1.dy**2 + src2.dy**2)
+    if dst.dy is not None:
+        dst.dy *= p.factor
+    # Eventually convert to initial data type
+    if p.restore_dtype:
+        dst.xydata = dst.xydata.astype(initial_dtype)
+    restore_data_outside_roi(dst, src1)
+    return dst
+
+
 def compute_difference(src1: SignalObj, src2: SignalObj) -> SignalObj:
     """Compute difference between two signals
 
@@ -228,6 +291,7 @@ def compute_difference(src1: SignalObj, src2: SignalObj) -> SignalObj:
     dst.y = src1.y - src2.y
     if dst.dy is not None:
         dst.dy = np.sqrt(src1.dy**2 + src2.dy**2)
+    restore_data_outside_roi(dst, src1)
     return dst
 
 
@@ -253,6 +317,7 @@ def compute_quadratic_difference(src1: SignalObj, src2: SignalObj) -> SignalObj:
         dst.data[src1.data < src2.data] = 0
     if dst.dy is not None:
         dst.dy = np.sqrt(src1.dy**2 + src2.dy**2)
+    restore_data_outside_roi(dst, src1)
     return dst
 
 
@@ -270,6 +335,7 @@ def compute_division(src1: SignalObj, src2: SignalObj) -> SignalObj:
     x1, y1 = src1.get_data()
     _x2, y2 = src2.get_data()
     dst.set_xydata(x1, y1 / np.array(y2, dtype=y1.dtype))
+    restore_data_outside_roi(dst, src1)
     return dst
 
 
@@ -340,7 +406,7 @@ def compute_swap_axes(src: SignalObj) -> SignalObj:
 
 
 def compute_abs(src: SignalObj) -> SignalObj:
-    """Compute absolute value
+    """Compute absolute value with :py:data:`numpy.absolute`
 
     Args:
         src: source signal
@@ -348,11 +414,11 @@ def compute_abs(src: SignalObj) -> SignalObj:
     Returns:
         Result signal object
     """
-    return Wrap11Func(np.abs)(src)
+    return Wrap11Func(np.absolute)(src)
 
 
 def compute_re(src: SignalObj) -> SignalObj:
-    """Compute real part
+    """Compute real part with :py:func:`numpy.real`
 
     Args:
         src: source signal
@@ -364,7 +430,7 @@ def compute_re(src: SignalObj) -> SignalObj:
 
 
 def compute_im(src: SignalObj) -> SignalObj:
-    """Compute imaginary part
+    """Compute imaginary part with :py:func:`numpy.imag`
 
     Args:
         src: source signal
@@ -386,7 +452,7 @@ class DataTypeSParam(gds.DataSet):
 
 
 def compute_astype(src: SignalObj, p: DataTypeSParam) -> SignalObj:
-    """Convert data type
+    """Convert data type with :py:func:`numpy.astype`
 
     Args:
         src: source signal
@@ -401,7 +467,7 @@ def compute_astype(src: SignalObj, p: DataTypeSParam) -> SignalObj:
 
 
 def compute_log10(src: SignalObj) -> SignalObj:
-    """Compute Log10
+    """Compute Log10 with :py:data:`numpy.log10`
 
     Args:
         src: source signal
@@ -413,7 +479,7 @@ def compute_log10(src: SignalObj) -> SignalObj:
 
 
 def compute_exp(src: SignalObj) -> SignalObj:
-    """Compute exponential
+    """Compute exponential with :py:data:`numpy.exp`
 
     Args:
         src: source signal
@@ -425,7 +491,7 @@ def compute_exp(src: SignalObj) -> SignalObj:
 
 
 def compute_sqrt(src: SignalObj) -> SignalObj:
-    """Compute square root
+    """Compute square root with :py:data:`numpy.sqrt`
 
     Args:
         src: source signal
@@ -443,7 +509,7 @@ class PowerParam(gds.DataSet):
 
 
 def compute_power(src: SignalObj, p: PowerParam) -> SignalObj:
-    """Compute power
+    """Compute power with :py:data:`numpy.power`
 
     Args:
         src: source signal
@@ -454,6 +520,7 @@ def compute_power(src: SignalObj, p: PowerParam) -> SignalObj:
     """
     dst = dst_11(src, "^", str(p.power))
     dst.y = np.power(src.y, p.power)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
@@ -467,7 +534,7 @@ class PeakDetectionParam(gds.DataSet):
 
 
 def compute_peak_detection(src: SignalObj, p: PeakDetectionParam) -> SignalObj:
-    """Peak detection
+    """Peak detection with :py:func:`cdl.algorithms.signal.peak_indexes`
 
     Args:
         src: source signal
@@ -487,7 +554,7 @@ def compute_peak_detection(src: SignalObj, p: PeakDetectionParam) -> SignalObj:
 
 
 def compute_normalize(src: SignalObj, p: NormalizeParam) -> SignalObj:
-    """Normalize data
+    """Normalize data with :py:func:`cdl.algorithms.signal.normalize`
 
     Args:
         src: source signal
@@ -499,11 +566,12 @@ def compute_normalize(src: SignalObj, p: NormalizeParam) -> SignalObj:
     dst = dst_11(src, "normalize", f"ref={p.method}")
     x, y = src.get_data()
     dst.set_xydata(x, alg.normalize(y, p.method))
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_derivative(src: SignalObj) -> SignalObj:
-    """Compute derivative
+    """Compute derivative with :py:func:`numpy.gradient`
 
     Args:
         src: source signal
@@ -514,11 +582,12 @@ def compute_derivative(src: SignalObj) -> SignalObj:
     dst = dst_11(src, "derivative")
     x, y = src.get_data()
     dst.set_xydata(x, np.gradient(y, x))
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_integral(src: SignalObj) -> SignalObj:
-    """Compute integral
+    """Compute integral with :py:func:`scipy.integrate.cumulative_trapezoid`
 
     Args:
         src: source signal
@@ -529,6 +598,7 @@ def compute_integral(src: SignalObj) -> SignalObj:
     dst = dst_11(src, "integral")
     x, y = src.get_data()
     dst.set_xydata(x, spt.cumulative_trapezoid(y, x, initial=0.0))
+    restore_data_outside_roi(dst, src)
     return dst
 
 
@@ -557,11 +627,12 @@ def compute_calibration(src: SignalObj, p: XYCalibrateParam) -> SignalObj:
         dst.set_xydata(p.a * x + p.b, y)
     else:
         dst.set_xydata(x, p.a * y + p.b)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_clip(src: SignalObj, p: ClipParam) -> SignalObj:
-    """Compute maximum data clipping
+    """Compute maximum data clipping with :py:func:`numpy.clip`
 
     Args:
         src: source signal
@@ -587,11 +658,12 @@ def compute_offset_correction(src: SignalObj, p: ROI1DParam) -> SignalObj:
     dst = dst_11(src, "offset_correction", f"{p.xmin:.3g}≤x≤{p.xmax:.3g}")
     _roi_x, roi_y = p.get_data(src)
     dst.y -= np.mean(roi_y)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_gaussian_filter(src: SignalObj, p: GaussianParam) -> SignalObj:
-    """Compute gaussian filter
+    """Compute gaussian filter with :py:func:`scipy.ndimage.gaussian_filter`
 
     Args:
         src: source signal
@@ -604,7 +676,7 @@ def compute_gaussian_filter(src: SignalObj, p: GaussianParam) -> SignalObj:
 
 
 def compute_moving_average(src: SignalObj, p: MovingAverageParam) -> SignalObj:
-    """Compute moving average
+    """Compute moving average with :py:func:`scipy.ndimage.uniform_filter`
 
     Args:
         src: source signal
@@ -617,7 +689,7 @@ def compute_moving_average(src: SignalObj, p: MovingAverageParam) -> SignalObj:
 
 
 def compute_moving_median(src: SignalObj, p: MovingMedianParam) -> SignalObj:
-    """Compute moving median
+    """Compute moving median with :py:func:`scipy.ndimage.median_filter`
 
     Args:
         src: source signal
@@ -630,7 +702,7 @@ def compute_moving_median(src: SignalObj, p: MovingMedianParam) -> SignalObj:
 
 
 def compute_wiener(src: SignalObj) -> SignalObj:
-    """Compute Wiener filter
+    """Compute Wiener filter with :py:func:`scipy.signal.wiener`
 
     Args:
         src: source signal
@@ -770,7 +842,8 @@ class BandStopFilterParam(BaseHighLowBandParam):
 
 
 def compute_filter(src: SignalObj, p: BaseHighLowBandParam) -> SignalObj:
-    """Compute frequency filter (low-pass, high-pass, band-pass, band-stop)
+    """Compute frequency filter (low-pass, high-pass, band-pass, band-stop),
+    with :py:func:`scipy.signal.filtfilt`
 
     Args:
         src: source signal
@@ -790,11 +863,12 @@ def compute_filter(src: SignalObj, p: BaseHighLowBandParam) -> SignalObj:
     dst = dst_11(src, name, suffix)
     b, a = p.get_filter_params(dst)
     dst.y = sps.filtfilt(b, a, dst.y)
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_fft(src: SignalObj, p: FFTParam | None = None) -> SignalObj:
-    """Compute FFT
+    """Compute FFT with :py:func:`cdl.algorithms.signal.fft1d`
 
     Args:
         src: source signal
@@ -813,7 +887,7 @@ def compute_fft(src: SignalObj, p: FFTParam | None = None) -> SignalObj:
 
 
 def compute_ifft(src: SignalObj, p: FFTParam | None = None) -> SignalObj:
-    """Compute iFFT
+    """Compute iFFT with :py:func:`cdl.algorithms.signal.ifft1d`
 
     Args:
         src: source signal
@@ -835,6 +909,7 @@ def compute_magnitude_spectrum(
     src: SignalObj, p: SpectrumParam | None = None
 ) -> SignalObj:
     """Compute magnitude spectrum
+    with :py:func:`cdl.algorithms.signal.magnitude_spectrum`
 
     Args:
         src: source signal
@@ -855,6 +930,7 @@ def compute_magnitude_spectrum(
 
 def compute_phase_spectrum(src: SignalObj) -> SignalObj:
     """Compute phase spectrum
+    with :py:func:`cdl.algorithms.signal.phase_spectrum`
 
     Args:
         src: source signal
@@ -873,6 +949,7 @@ def compute_phase_spectrum(src: SignalObj) -> SignalObj:
 
 def compute_psd(src: SignalObj, p: SpectrumParam | None = None) -> SignalObj:
     """Compute power spectral density
+    with :py:func:`cdl.algorithms.signal.psd`
 
     Args:
         src: source signal
@@ -899,7 +976,7 @@ class PolynomialFitParam(gds.DataSet):
 
 
 def compute_histogram(src: SignalObj, p: HistogramParam) -> SignalObj:
-    """Compute histogram
+    """Compute histogram with :py:func:`numpy.histogram`
 
     Args:
         src: source signal
@@ -908,12 +985,7 @@ def compute_histogram(src: SignalObj, p: HistogramParam) -> SignalObj:
     Returns:
         Result signal object
     """
-    # Extract data from ROIs:
-    datalist = []
-    for i_roi in src.iterate_roi_indexes():
-        datalist.append(src.get_data(i_roi)[1])
-    data = np.concatenate(datalist)
-
+    data = src.get_masked_view().compressed()
     suffix = p.get_suffix(data)  # Also updates p.lower and p.upper
 
     # Compute histogram:
@@ -961,7 +1033,7 @@ class InterpolationParam(gds.DataSet):
 def compute_interpolation(
     src1: SignalObj, src2: SignalObj, p: InterpolationParam
 ) -> SignalObj:
-    """Interpolate data
+    """Interpolate data with :py:func:`cdl.algorithms.signal.interpolate`
 
     Args:
         src1: source signal 1
@@ -1001,7 +1073,7 @@ class ResamplingParam(InterpolationParam):
 
 
 def compute_resampling(src: SignalObj, p: ResamplingParam) -> SignalObj:
-    """Resample data
+    """Resample data with :py:func:`cdl.algorithms.signal.interpolate`
 
     Args:
         src: source signal
@@ -1036,7 +1108,7 @@ class DetrendingParam(gds.DataSet):
 
 
 def compute_detrending(src: SignalObj, p: DetrendingParam) -> SignalObj:
-    """Detrend data
+    """Detrend data with :py:func:`scipy.signal.detrend`
 
     Args:
         src: source signal
@@ -1048,11 +1120,13 @@ def compute_detrending(src: SignalObj, p: DetrendingParam) -> SignalObj:
     dst = dst_11(src, "detrending", f"method={p.method}")
     x, y = src.get_data()
     dst.set_xydata(x, sps.detrend(y, type=p.method))
+    restore_data_outside_roi(dst, src)
     return dst
 
 
 def compute_convolution(src1: SignalObj, src2: SignalObj) -> SignalObj:
     """Compute convolution of two signals
+    with :py:func:`scipy.signal.convolve`
 
     Args:
         src1: source signal 1
@@ -1066,6 +1140,7 @@ def compute_convolution(src1: SignalObj, src2: SignalObj) -> SignalObj:
     _x2, y2 = src2.get_data()
     ynew = np.real(sps.convolve(y1, y2, mode="same"))
     dst.set_xydata(x1, ynew)
+    restore_data_outside_roi(dst, src1)
     return dst
 
 
@@ -1116,7 +1191,7 @@ class WindowingParam(gds.DataSet):
 
 def compute_windowing(src: SignalObj, p: WindowingParam) -> SignalObj:
     """Compute windowing (available methods: hamming, hanning, bartlett, blackman,
-    tukey, rectangular)
+    tukey, rectangular) with :py:func:`cdl.algorithms.signal.windowing`
 
     Args:
         dst: destination signal
@@ -1134,6 +1209,7 @@ def compute_windowing(src: SignalObj, p: WindowingParam) -> SignalObj:
         suffix += f", sigma={p.sigma:.3f}"
     dst = dst_11(src, "windowing", suffix)  # type: ignore
     dst.y = alg.windowing(dst.y, p.method, p.alpha)  # type: ignore
+    restore_data_outside_roi(dst, src)
     return dst
 
 
@@ -1238,7 +1314,7 @@ class FWHMParam(gds.DataSet):
 
 
 def compute_fwhm(obj: SignalObj, param: FWHMParam) -> ResultShape | None:
-    """Compute FWHM
+    """Compute FWHM with :py:func:`cdl.algorithms.signal.fwhm`
 
     Args:
         obj: source signal
@@ -1260,7 +1336,7 @@ def compute_fwhm(obj: SignalObj, param: FWHMParam) -> ResultShape | None:
 
 
 def compute_fw1e2(obj: SignalObj) -> ResultShape | None:
-    """Compute FW at 1/e²
+    """Compute FW at 1/e² with :py:func:`cdl.algorithms.signal.fw1e2`
 
     Args:
         obj: source signal
@@ -1295,7 +1371,7 @@ def compute_stats(obj: SignalObj) -> ResultProperties:
 
 
 def compute_bandwidth_3db(obj: SignalObj) -> ResultProperties:
-    """Compute bandwidth
+    """Compute bandwidth at -3 dB with :py:func:`cdl.algorithms.signal.bandwidth`
 
     Args:
         obj: source signal
@@ -1325,7 +1401,15 @@ class DynamicParam(gds.DataSet):
 
 
 def compute_dynamic_parameters(src: SignalObj, p: DynamicParam) -> ResultProperties:
-    """Compute Dynamic parameters (ENOB, SNR, SINAD, THD, SFDR)
+    """Compute Dynamic parameters
+    using the following functions:
+
+    - Freq: :py:func:`cdl.algorithms.signal.sinus_frequency`
+    - ENOB: :py:func:`cdl.algorithms.signal.enob`
+    - SNR: :py:func:`cdl.algorithms.signal.snr`
+    - SINAD: :py:func:`cdl.algorithms.signal.sinad`
+    - THD: :py:func:`cdl.algorithms.signal.thd`
+    - SFDR: :py:func:`cdl.algorithms.signal.sfdr`
 
     Args:
         src: source signal
@@ -1348,6 +1432,10 @@ def compute_dynamic_parameters(src: SignalObj, p: DynamicParam) -> ResultPropert
 
 def compute_sampling_rate_period(obj: SignalObj) -> ResultProperties:
     """Compute sampling rate and period
+    using the following functions:
+
+    - fs: :py:func:`cdl.algorithms.signal.sampling_rate`
+    - T: :py:func:`cdl.algorithms.signal.sampling_period`
 
     Args:
         obj: source signal
@@ -1366,7 +1454,7 @@ def compute_sampling_rate_period(obj: SignalObj) -> ResultProperties:
 
 
 def compute_contrast(obj: SignalObj) -> ResultProperties:
-    """Compute contrast"""
+    """Compute contrast with :py:func:`cdl.algorithms.signal.contrast`"""
     return calc_resultproperties(
         "contrast",
         obj,
