@@ -458,12 +458,11 @@ class AbstractCDLControl(abc.ABC):
         """Call compute function ``name`` in current panel's processor.
 
         Args:
-            name (str): Compute function name
-            param (guidata.dataset.DataSet | None): Compute function
-            parameter. Defaults to None.
+            name: Compute function name
+            param: Compute function parameter. Defaults to None.
 
-        Returns:
-            guidata.dataset.DataSet: Compute function result
+        Raises:
+            ValueError: unknown function
         """
 
     def __getattr__(self, name: str) -> Callable:
