@@ -26,31 +26,30 @@ from cdl.widgets import fitdialog, signalbaseline, signalpeak
 
 
 class SignalProcessor(BaseProcessor):
-    """Object handling signal processing: operations, processing, computing"""
+    """Object handling signal processing: operations, processing, analysis"""
 
     # pylint: disable=duplicate-code
 
     @qt_try_except()
     def compute_sum(self) -> None:
-        """Compute sum"""
+        """Compute sum with :py:func:`cdl.computation.signal.compute_addition`"""
         self.compute_n1("Σ", cps.compute_addition, title=_("Sum"))
 
     @qt_try_except()
-    def compute_addition_constant(
-        self, param: cpb.ConstantOperationParam | None = None
-    ) -> None:
-        """Compute sum with a constant"""
+    def compute_addition_constant(self, param: cpb.ConstantParam | None = None) -> None:
+        """Compute sum with a constant
+        with :py:func:`cdl.computation.signal.compute_addition_constant`"""
         self.compute_11(
             cps.compute_addition_constant,
             param,
-            paramclass=cpb.ConstantOperationParam,
+            paramclass=cpb.ConstantParam,
             title=_("Sum with constant"),
-            edit=True,
         )
 
     @qt_try_except()
     def compute_average(self) -> None:
-        """Compute average"""
+        """Compute average with :py:func:`cdl.computation.signal.compute_addition`
+        and divide by the number of signals"""
 
         def func_objs(new_obj: SignalObj, old_objs: list[SignalObj]) -> None:
             """Finalize average computation"""
@@ -64,27 +63,29 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_product(self) -> None:
-        """Compute product"""
+        """Compute product with :py:func:`cdl.computation.signal.compute_product`"""
         self.compute_n1("Π", cps.compute_product, title=_("Product"))
 
     @qt_try_except()
-    def compute_product_constant(
-        self, param: cpb.ConstantOperationParam | None = None
-    ) -> None:
-        """Compute product with a constant"""
+    def compute_product_constant(self, param: cpb.ConstantParam | None = None) -> None:
+        """Compute product with a constant
+        with :py:func:`cdl.computation.signal.compute_product_constant`"""
         self.compute_11(
             cps.compute_product_constant,
             param,
-            paramclass=cpb.ConstantOperationParam,
+            paramclass=cpb.ConstantParam,
             title=_("Product with constant"),
-            edit=True,
         )
 
     @qt_try_except()
     def compute_roi_extraction(
         self, param: cdl.param.ROIDataParam | None = None
     ) -> None:
-        """Extract Region Of Interest (ROI) from data"""
+        """Extract Region Of Interest (ROI) from data with:
+
+        - :py:func:`cdl.computation.signal.extract_multiple_roi` for single ROI
+        - :py:func:`cdl.computation.signal.extract_single_roi` for multiple ROIs
+        """
         param = self._get_roidataparam(param)
         if param is None or param.is_empty:
             return
@@ -97,58 +98,70 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_swap_axes(self) -> None:
-        """Swap data axes"""
+        """Swap data axes with :py:func:`cdl.computation.signal.compute_swap_axes`"""
         self.compute_11(cps.compute_swap_axes, title=_("Swap axes"))
 
     @qt_try_except()
     def compute_abs(self) -> None:
-        """Compute absolute value"""
+        """Compute absolute value with :py:func:`cdl.computation.signal.compute_abs`"""
         self.compute_11(cps.compute_abs, title=_("Absolute value"))
 
     @qt_try_except()
     def compute_re(self) -> None:
-        """Compute real part"""
+        """Compute real part with :py:func:`cdl.computation.signal.compute_re`"""
         self.compute_11(cps.compute_re, title=_("Real part"))
 
     @qt_try_except()
     def compute_im(self) -> None:
-        """Compute imaginary part"""
+        """Compute imaginary part with :py:func:`cdl.computation.signal.compute_im`"""
         self.compute_11(cps.compute_im, title=_("Imaginary part"))
 
     @qt_try_except()
     def compute_astype(self, param: cdl.param.DataTypeSParam | None = None) -> None:
-        """Convert data type"""
+        """Convert data type with :py:func:`cdl.computation.signal.compute_astype`"""
         self.compute_11(
             cps.compute_astype, param, cps.DataTypeSParam, title=_("Convert data type")
         )
 
     @qt_try_except()
     def compute_log10(self) -> None:
-        """Compute Log10"""
+        """Compute Log10 with :py:func:`cdl.computation.signal.compute_log10`"""
         self.compute_11(cps.compute_log10, title="Log10")
 
     @qt_try_except()
     def compute_exp(self) -> None:
-        """Compute Log10"""
+        """Compute Log10 with :py:func:`cdl.computation.signal.compute_exp`"""
         self.compute_11(cps.compute_exp, title=_("Exponential"))
 
     @qt_try_except()
     def compute_sqrt(self) -> None:
-        """Compute square root"""
+        """Compute square root with :py:func:`cdl.computation.signal.compute_sqrt`"""
         self.compute_11(cps.compute_sqrt, title=_("Square root"))
 
     @qt_try_except()
     def compute_power(self, param: cps.PowerParam | None = None) -> None:
-        """Compute power"""
-        if param is None:
-            param = cps.PowerParam()
-        self.compute_11(
-            cps.compute_power, param, cps.PowerParam, title="Power", edit=True
+        """Compute power with :py:func:`cdl.computation.signal.compute_power`"""
+        self.compute_11(cps.compute_power, param, cps.PowerParam, title="Power")
+
+    @qt_try_except()
+    def compute_arithmetic(
+        self, obj2: SignalObj | None = None, param: cpb.ArithmeticParam | None = None
+    ) -> None:
+        """Compute arithmetic operation between two signals
+        with :py:func:`cdl.computation.signal.compute_arithmetic`"""
+        self.compute_n1n(
+            obj2,
+            _("signal to operate with"),
+            cps.compute_arithmetic,
+            param=param,
+            paramclass=cpb.ArithmeticParam,
+            title=_("Arithmetic"),
         )
 
     @qt_try_except()
     def compute_difference(self, obj2: SignalObj | None = None) -> None:
-        """Compute difference between two signals"""
+        """Compute difference between two signals
+        with :py:func:`cdl.computation.signal.compute_difference`"""
         self.compute_n1n(
             obj2,
             _("signal to subtract"),
@@ -158,20 +171,21 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_difference_constant(
-        self, param: cpb.ConstantOperationParam | None = None
+        self, param: cpb.ConstantParam | None = None
     ) -> None:
-        """Compute difference with a constant"""
+        """Compute difference with a constant
+        with :py:func:`cdl.computation.signal.compute_difference_constant`"""
         self.compute_11(
             cps.compute_difference_constant,
             param,
-            paramclass=cpb.ConstantOperationParam,
+            paramclass=cpb.ConstantParam,
             title=_("Difference with constant"),
-            edit=True,
         )
 
     @qt_try_except()
     def compute_quadratic_difference(self, obj2: SignalObj | None = None) -> None:
-        """Compute quadratic difference between two signals"""
+        """Compute quadratic difference between two signals
+        with :py:func:`cdl.computation.signal.compute_quadratic_difference`"""
         self.compute_n1n(
             obj2,
             _("signal to subtract"),
@@ -181,7 +195,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_division(self, obj2: SignalObj | None = None) -> None:
-        """Compute division between two signals"""
+        """Compute division between two signals
+        with :py:func:`cdl.computation.signal.compute_division`"""
         self.compute_n1n(
             obj2,
             _("divider"),
@@ -189,25 +204,23 @@ class SignalProcessor(BaseProcessor):
             title=_("Division"),
         )
 
-    qt_try_except()
-
-    def compute_division_constant(
-        self, param: cpb.ConstantOperationParam | None = None
-    ) -> None:
-        """Compute division by a constant"""
+    @qt_try_except()
+    def compute_division_constant(self, param: cpb.ConstantParam | None = None) -> None:
+        """Compute division by a constant
+        with :py:func:`cdl.computation.signal.compute_division_constant`"""
         self.compute_11(
             cps.compute_division_constant,
             param,
-            paramclass=cpb.ConstantOperationParam,
+            paramclass=cpb.ConstantParam,
             title=_("Division by constant"),
-            edit=True,
         )
 
     @qt_try_except()
     def compute_peak_detection(
         self, param: cdl.param.PeakDetectionParam | None = None
     ) -> None:
-        """Detect peaks from data"""
+        """Detect peaks from data
+        with :py:func:`cdl.computation.signal.compute_peak_detection`"""
         obj = self.panel.objview.get_sel_objects(include_groups=True)[0]
         edit, param = self.init_param(
             param, cps.PeakDetectionParam, _("Peak detection")
@@ -223,32 +236,34 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_reverse_x(self) -> None:
-        """Reverse X axis"""
+        """Reverse X axis with :py:func:`cdl.computation.signal.compute_reverse_x`"""
         self.compute_11(cps.compute_reverse_x, title=_("Reverse X axis"))
 
     # ------Signal Processing
     @qt_try_except()
     def compute_normalize(self, param: cdl.param.NormalizeParam | None = None) -> None:
-        """Normalize data"""
+        """Normalize data with :py:func:`cdl.computation.signal.compute_normalize`"""
         self.compute_11(
             cps.compute_normalize, param, cps.NormalizeParam, title=_("Normalize")
         )
 
     @qt_try_except()
     def compute_derivative(self) -> None:
-        """Compute derivative"""
+        """Compute derivative
+        with :py:func:`cdl.computation.signal.compute_derivative`"""
         self.compute_11(cps.compute_derivative, title=_("Derivative"))
 
     @qt_try_except()
     def compute_integral(self) -> None:
-        """Compute integral"""
+        """Compute integral with :py:func:`cdl.computation.signal.compute_integral`"""
         self.compute_11(cps.compute_integral, title=_("Integral"))
 
     @qt_try_except()
     def compute_calibration(
         self, param: cdl.param.XYCalibrateParam | None = None
     ) -> None:
-        """Compute data linear calibration"""
+        """Compute data linear calibration
+        with :py:func:`cdl.computation.signal.compute_calibration`"""
         self.compute_11(
             cps.compute_calibration,
             param,
@@ -259,12 +274,14 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_clip(self, param: cpb.ClipParam | None = None) -> None:
-        """Compute maximum data clipping"""
+        """Compute maximum data clipping
+        with :py:func:`cdl.computation.signal.compute_clip`"""
         self.compute_11(cps.compute_clip, param, cpb.ClipParam, title=_("Clipping"))
 
     @qt_try_except()
     def compute_offset_correction(self, param: ROI1DParam | None = None) -> None:
-        """Compute offset correction"""
+        """Compute offset correction
+        with :py:func:`cdl.computation.signal.compute_offset_correction`"""
         obj = self.panel.objview.get_sel_objects(include_groups=True)[0]
         if param is None:
             dlg = signalbaseline.SignalBaselineDialog(obj, parent=self.panel.parent())
@@ -277,7 +294,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_gaussian_filter(self, param: cpb.GaussianParam | None = None) -> None:
-        """Compute gaussian filter"""
+        """Compute gaussian filter
+        with :py:func:`cdl.computation.signal.compute_gaussian_filter`"""
         self.compute_11(
             cps.compute_gaussian_filter,
             param,
@@ -289,7 +307,8 @@ class SignalProcessor(BaseProcessor):
     def compute_moving_average(
         self, param: cpb.MovingAverageParam | None = None
     ) -> None:
-        """Compute moving average"""
+        """Compute moving average
+        with :py:func:`cdl.computation.signal.compute_moving_average`"""
         self.compute_11(
             cps.compute_moving_average,
             param,
@@ -299,7 +318,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_moving_median(self, param: cpb.MovingMedianParam | None = None) -> None:
-        """Compute moving median"""
+        """Compute moving median
+        with :py:func:`cdl.computation.signal.compute_moving_median`"""
         self.compute_11(
             cps.compute_moving_median,
             param,
@@ -309,7 +329,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_wiener(self) -> None:
-        """Compute Wiener filter"""
+        """Compute Wiener filter
+        with :py:func:`cdl.computation.signal.compute_wiener`"""
         self.compute_11(cps.compute_wiener, title=_("Wiener filter"))
 
     def __freq_filter(
@@ -337,40 +358,44 @@ class SignalProcessor(BaseProcessor):
     def compute_lowpass(
         self, param: cdl.param.LowPassFilterParam | None = None
     ) -> None:
-        """Compute high-pass filter"""
+        """Compute high-pass filter
+        with :py:func:`cdl.computation.signal.compute_filter`"""
         self.__freq_filter(param, cdl.param.LowPassFilterParam, _("Low-pass filter"))
 
     @qt_try_except()
     def compute_highpass(
         self, param: cdl.param.HighPassFilterParam | None = None
     ) -> None:
-        """Compute high-pass filter"""
+        """Compute high-pass filter
+        with :py:func:`cdl.computation.signal.compute_filter`"""
         self.__freq_filter(param, cdl.param.HighPassFilterParam, _("High-pass filter"))
 
     @qt_try_except()
     def compute_bandpass(
         self, param: cdl.param.BandPassFilterParam | None = None
     ) -> None:
-        """Compute band-pass filter"""
+        """Compute band-pass filter
+        with :py:func:`cdl.computation.signal.compute_filter`"""
         self.__freq_filter(param, cdl.param.BandPassFilterParam, _("Band-pass filter"))
 
     @qt_try_except()
     def compute_bandstop(
         self, param: cdl.param.BandStopFilterParam | None = None
     ) -> None:
-        """Compute band-stop filter"""
+        """Compute band-stop filter
+        with :py:func:`cdl.computation.signal.compute_filter`"""
         self.__freq_filter(param, cdl.param.BandStopFilterParam, _("Band-stop filter"))
 
     @qt_try_except()
     def compute_fft(self, param: cdl.param.FFTParam | None = None) -> None:
-        """Compute iFFT"""
+        """Compute FFT with :py:func:`cdl.computation.signal.compute_fft`"""
         if param is None:
             param = cpb.FFTParam.create(shift=Conf.proc.fft_shift_enabled.get())
         self.compute_11(cps.compute_fft, param, title=_("FFT"), edit=False)
 
     @qt_try_except()
     def compute_ifft(self, param: cdl.param.FFTParam | None = None) -> None:
-        """Compute FFT"""
+        """Compute iFFT with :py:func:`cdl.computation.signal.compute_ifft`"""
         if param is None:
             param = cpb.FFTParam.create(shift=Conf.proc.fft_shift_enabled.get())
         self.compute_11(cps.compute_ifft, param, title=_("iFFT"), edit=False)
@@ -379,7 +404,8 @@ class SignalProcessor(BaseProcessor):
     def compute_magnitude_spectrum(
         self, param: cdl.param.SpectrumParam | None = None
     ) -> None:
-        """Compute magnitude spectrum"""
+        """Compute magnitude spectrum
+        with :py:func:`cdl.computation.signal.compute_magnitude_spectrum`"""
         self.compute_11(
             cps.compute_magnitude_spectrum,
             param,
@@ -389,12 +415,14 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_phase_spectrum(self) -> None:
-        """Compute phase spectrum"""
+        """Compute phase spectrum
+        with :py:func:`cdl.computation.signal.compute_phase_spectrum`"""
         self.compute_11(cps.compute_phase_spectrum, title=_("Phase spectrum"))
 
     @qt_try_except()
     def compute_psd(self, param: cdl.param.SpectrumParam | None = None) -> None:
-        """Compute power spectral density"""
+        """Compute power spectral density
+        with :py:func:`cdl.computation.signal.compute_psd`"""
         self.compute_11(cps.compute_psd, param, cdl.param.SpectrumParam, title=_("PSD"))
 
     @qt_try_except()
@@ -403,7 +431,8 @@ class SignalProcessor(BaseProcessor):
         obj2: SignalObj | None = None,
         param: cdl.param.InterpolationParam | None = None,
     ):
-        """Compute interpolation"""
+        """Compute interpolation
+        with :py:func:`cdl.computation.signal.compute_interpolation`"""
         self.compute_n1n(
             obj2,
             _("signal for X values"),
@@ -415,7 +444,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_resampling(self, param: cdl.param.ResamplingParam | None = None):
-        """Compute resampling"""
+        """Compute resampling
+        with :py:func:`cdl.computation.signal.compute_resampling`"""
         edit, param = self.init_param(param, cps.ResamplingParam, _("Resampling"))
         if edit:
             obj = self.panel.objview.get_sel_objects(include_groups=True)[0]
@@ -437,7 +467,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_detrending(self, param: cdl.param.DetrendingParam | None = None):
-        """Compute detrending"""
+        """Compute detrending
+        with :py:func:`cdl.computation.signal.compute_detrending`"""
         self.compute_11(
             cps.compute_detrending,
             param,
@@ -447,7 +478,8 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_convolution(self, obj2: SignalObj | None = None) -> None:
-        """Compute convolution"""
+        """Compute convolution
+        with :py:func:`cdl.computation.signal.compute_convolution`"""
         self.compute_n1n(
             obj2,
             _("signal to convolve with"),
@@ -457,21 +489,15 @@ class SignalProcessor(BaseProcessor):
 
     @qt_try_except()
     def compute_windowing(self, param: cdl.param.WindowingParam | None = None) -> None:
-        """Compute windowing"""
+        """Compute windowing
+        with :py:func:`cdl.computation.signal.compute_windowing`"""
         self.compute_11(
             cps.compute_windowing,
             param,
             cdl.param.WindowingParam,
             title=_("Windowing"),
-            edit=True,
         )
 
-    @qt_try_except()
-    def compute_fit(self, name, fitdlgfunc):
-        """Compute fitting curve"""
-        for obj in self.panel.objview.get_sel_objects():
-            self.__row_compute_fit(obj, name, fitdlgfunc)
-
     @qt_try_except()
     def compute_polyfit(
         self, param: cdl.param.PolynomialFitParam | None = None
@@ -510,9 +536,20 @@ class SignalProcessor(BaseProcessor):
             # Creating new plot item
             self.panel.add_object(signal)
 
+    @qt_try_except()
+    def compute_fit(self, title: str, fitdlgfunc: Callable) -> None:
+        """Compute fitting curve using an interactive dialog
+
+        Args:
+            title: Title of the dialog
+            fitdlgfunc: Fitting dialog function
+        """
+        for obj in self.panel.objview.get_sel_objects():
+            self.__row_compute_fit(obj, title, fitdlgfunc)
+
     @qt_try_except()
     def compute_multigaussianfit(self) -> None:
-        """Compute multi-Gaussian fitting curve"""
+        """Compute multi-Gaussian fitting curve using an interactive dialog"""
         fitdlgfunc = fitdialog.multigaussianfit
         for obj in self.panel.objview.get_sel_objects():
             dlg = signalpeak.SignalPeakDetectionDialog(obj, parent=self.panel)
@@ -527,60 +564,66 @@ class SignalProcessor(BaseProcessor):
 
                 self.__row_compute_fit(obj, _("Multi-Gaussian fit"), multigaussianfit)
 
-    # ------Signal Computing
+    # ------Signal Analysis
     @qt_try_except()
     def compute_fwhm(
         self, param: cdl.param.FWHMParam | None = None
     ) -> dict[str, ResultShape]:
-        """Compute FWHM"""
+        """Compute FWHM with :py:func:`cdl.computation.signal.compute_fwhm`"""
         return self.compute_10(cps.compute_fwhm, param, cps.FWHMParam, title=_("FWHM"))
 
     @qt_try_except()
     def compute_fw1e2(self) -> dict[str, ResultShape]:
-        """Compute FW at 1/e²"""
+        """Compute FW at 1/e² with :py:func:`cdl.computation.signal.compute_fw1e2`"""
         return self.compute_10(cps.compute_fw1e2, title=_("FW") + "1/e²")
 
     @qt_try_except()
     def compute_stats(self) -> dict[str, ResultProperties]:
-        """Compute data statistics"""
+        """Compute data statistics
+        with :py:func:`cdl.computation.signal.compute_stats`"""
         return self.compute_10(cps.compute_stats, title=_("Statistics"))
 
     @qt_try_except()
     def compute_histogram(
         self, param: cdl.param.HistogramParam | None = None
     ) -> dict[str, ResultShape]:
-        """Compute histogram"""
+        """Compute histogram
+        with :py:func:`cdl.computation.signal.compute_histogram`"""
         return self.compute_11(
             cps.compute_histogram, param, cps.HistogramParam, title=_("Histogram")
         )
 
     @qt_try_except()
     def compute_contrast(self) -> dict[str, ResultProperties]:
-        """Compute contrast"""
+        """Compute contrast with :py:func:`cdl.computation.signal.compute_contrast`"""
         return self.compute_10(cps.compute_contrast, title=_("Contrast"))
 
     @qt_try_except()
     def compute_x_at_minmax(self) -> dict[str, ResultProperties]:
-        """Compute x at min/max"""
+        """Compute x at min/max
+        with :py:func:`cdl.computation.signal.compute_x_at_minmax`"""
         return self.compute_10(cps.compute_x_at_minmax, title="X @ min,max")
 
     @qt_try_except()
     def compute_sampling_rate_period(self) -> dict[str, ResultProperties]:
-        """Compute sampling rate and period (mean and std)"""
+        """Compute sampling rate and period (mean and std)
+        with :py:func:`cdl.computation.signal.compute_sampling_rate_period`"""
         return self.compute_10(
             cps.compute_sampling_rate_period, title=_("Sampling rate and period")
         )
 
     @qt_try_except()
     def compute_bandwidth_3db(self) -> None:
-        """Compute bandwidth"""
+        """Compute bandwidth at -3dB
+        with :py:func:`cdl.computation.signal.compute_bandwidth_3db`"""
         self.compute_10(cps.compute_bandwidth_3db, title=_("Bandwidth"))
 
     @qt_try_except()
     def compute_dynamic_parameters(
         self, param: cps.DynamicParam | None = None
     ) -> dict[str, ResultProperties]:
-        """Compute Dynamic Parameters (ENOB, SINAD, THD, SFDR, SNR)"""
+        """Compute Dynamic Parameters (ENOB, SINAD, THD, SFDR, SNR)
+        with :py:func:`cdl.computation.signal.compute_dynamic_parameters`"""
         return self.compute_10(
             cps.compute_dynamic_parameters,
             param,
